@@ -1,5 +1,6 @@
+from .command_handler import CommandHandler
 from .formatters import *
 from .lemonbar import Lemonbar
 from .models import *
-from .module import Module
+from .module import Module, EventHandler
 from .modules import *
